@@ -48,13 +48,23 @@ HBASE_BACKUP_VERSION = (
 # create-cluster options help text
 
 CREATE_CLUSTER_DESCRIPTION = (
-    'Creates an Amazon EMR cluster with the specified configurations.\n'
-    '\nQuick start:\n'
-    '\naws emr create-cluster --release-label <release-label>'
-    ' --instance-type <instance-type> --instance-count <instance-count>\n'
-    '\nValues for the following can be set in the AWS CLI'
-    ' config file using the "aws configure set" command: --service-role, --log-uri,'
-    ' and InstanceProfile and KeyName arguments under --ec2-attributes.')
+    'Creates an Amazon EMR cluster with the specified configurations. '
+    'Quick start: '
+    'aws emr create-cluster --release-label <release-label> '
+    '--instance-type <instance-type> --instance-count <instance-count>'
+    'Values for the following can be set in the AWS CLI. '
+    'config file using the <code>aws configure set</code> command: <code>--service-role, --log-uri, '
+    'and InstanceProfile and KeyName arguments under --ec2-attributes.')
+
+DESCRIBE_CLUSTER_DESCRIPTION = (
+    'Provides  cluster-level details including status, hardware '
+    'and software configuration, VPC settings, bootstrap '
+    'actions, instance groups and so on. '
+    'Permissions needed for describe-cluster include '
+    'elasticmapreduce:ListBootstrapActions, '
+    'elasticmapreduce:ListInstanceFleets, '
+    'elasticmapreduce:DescribeCluster, '
+    'and elasticmapreduce:ListInstanceGroups.')
 
 CLUSTER_NAME = (
     '<p>The name of the cluster. If not provided, the default is "Development Cluster".</p>')
@@ -113,6 +123,11 @@ RELEASE_LABEL = (
     ' and later. Use <code>--ami-version</code> for earlier versions.'
     ' You cannot specify both a release label and AMI version.</p>')
 
+OS_RELEASE_LABEL = (
+    '<p>Specifies a particular Amazon Linux release for all nodes in a cluster'
+    ' launch request. If a release is not specified, EMR uses the latest validated' 
+    ' Amazon Linux release for cluster launch.</p>')
+
 CONFIGURATIONS = (
     '<p>Specifies a JSON file that contains configuration classifications,'
     ' which you can use to customize applications that Amazon EMR installs'
@@ -261,14 +276,13 @@ SCALE_DOWN_BEHAVIOR = (
     ' terminate EC2 instances at the instance-hour boundary, regardless of when'
     ' the request to terminate was submitted.</li>'
 )
+
 VISIBILITY = (
-    '<p>Specifies whether the cluster is visible to all IAM users of'
-    ' the AWS account associated with the cluster. If set to'
-    ' <code>--visible-to-all-users</code>, all IAM users of that AWS account'
-    ' can view it. If they have the proper policy permissions set, they can '
-    ' also manage the cluster. If it is set to <code>--no-visible-to-all-users</code>,'
-    ' only the IAM user that created the cluster can view and manage it. '
-    ' Clusters are visible by default.</p>')
+    '<p>Specifies whether the cluster is visible to all IAM users'
+    ' of the AWS account associated with the cluster. If a user'
+    ' has the proper policy permissions set, they can also manage the cluster.</p>'
+    '<p>Visibility is on by default. The <code>--no-visible-to-all-users</code> option'
+    ' is no longer supported. To restrict cluster visibility, use an IAM policy.</p>')
 
 DEBUGGING = (
     '<p>Specifies that the debugging tool is enabled for the cluster,'
@@ -401,7 +415,7 @@ KERBEROS_ATTRIBUTES = (
      ' with a KDC in a different realm. This is the cross-realm principal password,'
      ' which must be identical across realms.</li>'
      ' <li><code>ADDomainJoinUser</code> - Required when establishing trust with an Active Directory'
-     ' domain. This is the User logon name of an AD account with sufficient privileges to join resouces to the domain.</li>'
+     ' domain. This is the User logon name of an AD account with sufficient privileges to join resources to the domain.</li>'
      ' <li><code>ADDomainJoinPassword</code> - The AD password for <code>ADDomainJoinUser</code>.</li>')
 
 # end create-cluster options help descriptions
